Tool for defining dict lists or jsonlines batch processing pipelines.

See tests for usage on the first case. You can also process a jsonlines batch file using the command line tool.

For running tests:

    > nosetest3 tests/test_transform.py

Usage:

```
python -m json_pipeline.transform
```
